@@ -8,7 +8,7 @@ import threading
 import traceback
 
 from adam import log
-from adam.commands.frontend.code_utils import get_available_port
+from adam.commands.deploy.code_utils import get_available_port
 from adam.config import Config
 from adam.sso.idp import Idp
 from adam.app_session import AppSession, IdpLogin
